(************** Content-type: application/mathematica **************

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     18537,        440]*)
(*NotebookOutlinePosition[     19396,        469]*)
(*  CellTagsIndexPosition[     19352,        465]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["\<\
Notebooks for
Integrated Applications\
\>", "Title",
  TextAlignment->Center,
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
pt (novembre 1994) da John M. Novak, April 1994
\
\>", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
The Mathematica  notebook interface is a useful tool for informing users and \
creating \"live\" documents. These characteristics allow notebooks to be used \
to good effect in any Mathematica-based application. A number of issues of \
good notebook design need to be considered in this context, including \
appropriate contents and portability.\
\>", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[CellGroupData[{

Cell["What Should Notebooks Contain?", "Subtitle",
  TextAlignment->Center,
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
The notebook front end provides Mathematica with a very flexible document \
interface. However, in the context of a Mathematica-based application, only \
some of the possible ways of using the front end should be employed. A \
notebook in an application is best used as an expository tool, or as \
application documentation. Generally it is not a good idea to place the \
application code in notebooks (or, at least, not in notebooks intended to be \
opened by the user).\
\>", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
Mathematica applications can take many forms, so very few of the rules given \
here are hard and fast. However, general principles of good design suggest \
that you use techniques such as information hiding to simplify the interface \
of your application. This will usually give your users a better experience \
with your application, and make it more useful overall.\
\>", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
This principle means placing the implementation code in packages, and showing \
the use of those packages in the notebooks. While notebooks can be useful for \
documenting code as it is developed, this information is generally not useful \
to users; the application should not present its code in notebook form. Note \
that this is distinct from the case where the purpose of the notebook is to \
demonstrate code-development techniques; code developed in this fashion \
usually is less complete in some fashion than full application code, and can \
be presented in an interactive fashion.\
\>", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
Notebooks can act as live books, containing text explaining the application \
or employing it for problem solving. The text can be mixed with the actual \
examples of the use of application functions, presented so that the user can \
modify parameters or other aspects of the function calls. This is especially \
useful when the application is courseware; in many cases, the application \
will consist only of notebooks, with no auxiliary packages.\
\>", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
A user reads a notebook for a particular purpose: to learn a concept, to \
solve a particular problem, or to learn how to use an application. As such, \
information that is extraneous to the primary objective should not be placed \
in the notebook. For some advanced users, implementation details become \
important; these users can always delve into packages, where detailed \
information on implementation should be placed. Again, simplify the interface \
for the user, and the user will thank you.\
\>", "Text",
  ImageRegion->{{0, 1}, {0, 1}}]
}, Closed]],

Cell[CellGroupData[{

Cell["How Should Documents be Structured?", "Subtitle",
  TextAlignment->Center,
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
The hierarchical structure of the notebook allows the use of another aspect \
of information hiding. Essentially, you can delay presentation of various \
concepts until the user is ready by placing information in closed cell \
groups. The tree structure of cells allows you to summarize the contents of \
parts of the notebook in cell headings. The user can choose the heading of \
interest, where the topic will be expanded upon.\
\>", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
You can model the presentation of information in a notebook the same way you \
would a book, with chapters, sections, subsections, and so forth. To reduce \
the amount of information presented to the user at once (and, incidentally, \
to reduce memory consumption so users with smaller machines can handle the \
documents), it is often a good idea to place separate \"chapters\" in \
separate notebooks.\
\>", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
The information-hiding technique is particularly useful in courseware that \
contains problem sets. The problem can be presented in a cell visible to the \
student, with the answer in a closed cell that the student opens after \
solving the problem. (This technique has been used in many of the popular \
instances of calculus courseware.)\
\>", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
The live input in a notebook must be carefully handled. For instance, do not \
use direct references to items in the command history (e.g., %52, Out[5]). In \
general, the user's session will not match your session. Relative references \
are acceptable in a close-knit group of computations (e.g., %, %%). Generally \
it is not good to refer to anything more than three prior computations back, \
and ideally all the code referred to in this fashion should be on-screen at \
once. For more distant references, assign output to descriptive symbols, and \
reference those symbols in the later calculations. If it is likely that the \
user may not be able to easily locate the prior reference, document it in the \
text or reenter the definition.\
\>", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
The typical application notebook contains a brief summary of the purpose \
and/or the contents of the notebook after the title. This portion of the \
document is usually grouped so that it is visible when the title is visible. \
Some initialization code may be placed after the introduction. If it is \
simple (e.g., loading a package) it may be visible to the user. If it is more \
complex, and less relevant to the purpose of the notebook (e.g., setting font \
styles for graphics, setting paths), it may be in a closed group or cell. \
Initialization material of this sort should go in initialization cells. \
Finally, the text of the document is given, divided into appropriate \
sections.\
\>", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
These principles are essentially \"rules of thumb\" for clear notebooks; they \
will not apply to every notebook. Further, as more capabilities are added to \
future versions of the notebook front end, the straightforward tree structure \
may become less applicable. Keep in mind that the goal is to make information \
accessible to the user.\
\>", "Text",
  ImageRegion->{{0, 1}, {0, 1}}]
}, Closed]],

Cell[CellGroupData[{

Cell["How Do You Create Portable Notebooks?", "Subtitle",
  TextAlignment->Center,
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
The notebook format is essentially portable across the various platforms that \
have notebook front ends. However, some aspects of the portability are \
limited. Generally, the text, code, and graphics created in Mathematica on \
one platform will be readable and useable on another. However, the style of \
the notebook may not be identical, and imported graphics may not transport. \
Some of the points to keep in mind if a notebook is intended to be ported \
while maintaining a substantially similar appearance are described in this \
section.\
\>", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
There are two major types of Mathematica notebook front ends: those based on \
the Macintosh version of the front  end (which currently includes the Power \
Macintosh, NeXT and X Windows front ends), and those based on the Microsoft \
Windows version of the front end (including all versions for Windows NT). \
Both of these systems are continually growing and adding new features, so the \
information given here is subject to change. This information was current for \
Version 2.2. For convenience, front ends based on the Macintosh will be \
referred to as \"Mac-style\" front ends, while those based on MS Windows will \
be referred to as \"Win-style\" front ends.\
\>", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[CellGroupData[{

Cell["Fonts", "Subsubtitle",
  TextAlignment->Center,
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
Fonts are the biggest problem in cross-platform notebook compatibility. The \
first problem of this type comes from fonts that do not exist on the target \
machine. For maximum compatibility, use only fonts that are virtually \
guaranteed to exist on all machines; Times and Courier are good choices.\
\>", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
A major portability problem arises from use of extended character sets. Most \
systems support extended character sets for a given font, allowing, for \
instance, characters with umlauts, or a subset of Greek characters. \
(Technically, these are characters above ASCII 127.) In general, these \
character sets are not identical across platforms. The characters will be \
incorrect when the notebook is opened on another platform. This is especially \
a problem with Macintosh and NeXT notebooks, since users of these platforms \
are used to drawing upon extended character sets. Unfortunately, there is \
currently no solution for this problem. To work aound it you should spell out \
Greek characters in a Mathematica-like notation (e.g., Pi).\
\>", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
Multiple-font cells are not currently portable to the Win-style front ends. \
While a notebook with multiple fonts in a given cell can be read by the \
Windows front end, the front end will use whatever font has been assigned to \
the entire cell for all characters. Use of styles to indicate other fonts for \
particular words in a cell is ignored. (Thus, italicization of Mathematica \
does not occur.) This will eventually be corrected in a future version of \
Mathematica for Windows. Multiple-font cells generally move well between \
Mac-style front ends.\
\>", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
Note that in the current version of Mac-style front ends, tabs are not \
correctly handled in multi-font cells. In the MS Windows front end, tabs \
cannot be reset, they are automatically equivalent to 8 spaces. In Mac-style \
front ends, tab size can be set, but this applies to the front end as a \
whole, not the notebook. This can cause alignment problems when notebooks are \
moved between platforms. In general, you should use only multiple spaces, not \
tabs, to align text at the current time. (This works best, of course, when \
monospaced fonts such as \"Courier\" are involved.)\
\>", "Text",
  ImageRegion->{{0, 1}, {0, 1}}]
}, Closed]],

Cell[CellGroupData[{

Cell["Graphics", "Subsubtitle",
  TextAlignment->Center,
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
Most graphics created as Mathematica output should be completely portable. \
The only known exceptions are top-level Mathematica commands that generate \
raw PostScript (e.g., the Arrow primitive from the Graphics`Arrow` \
package).\
\>", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
Some authors may consider modifications to color to be a problem. Often when \
graphics are moved between platforms (or even between different computers \
with the same architecture) colors with an identical specification in \
Mathematica appear different on the screen. Generally, this is unavoidable. \
Good color-correction routines for a particular system may minimize this \
distortion, but some differences will usually occur.\
\>", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
Graphics generated outside of Mathematica and pasted into a notebook are the \
greatest problem. First note that most externally generated graphics are kept \
only in the binary portion of a notebook, which is not portable. This means \
that such graphics are lost when the notebook is moved.\
\>", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
In general, it is best to avoid the use of externally generated graphics in a \
notebook, unless you are on a platform that will allow you to successfully \
convert to PostScript. If you are, such conversion should be performed \
immediately on import of the graphic.\
\>", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
Certain kinds of machine-specific graphics will probably not convert well at \
all. QuickTime animations from a Macintosh are a good example.\
\>", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
You may occasionally encounter problems with fonts in graphics. Most problems \
are identical to those explained in the preceding section. However, fonts in \
graphics usually require more precise placement.\
\>", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
There is a difference in graphics positioning between Mac-style front ends \
and the Win-style front ends. In the Windows front end, graphics are \
positioned with respect to the left page margin, while in the Macintosh front \
end, they are positioned with respect to the left cell margin. (Note that the \
Windows front end does not currently support cell margins.) This causes \
graphics to be incorrectly positioned on the screen in a ported notebook. You \
may need to reposition graphics by hand in some cases for ideal appearance. \
It is possible to create automated routines to convert notebook files that \
will work for most cases. This involves tranforming notebook cell header \
lines.\
\>", "Text",
  ImageRegion->{{0, 1}, {0, 1}}]
}, Closed]],

Cell[CellGroupData[{

Cell["Other Issues", "Subsubtitle",
  TextAlignment->Center,
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
The MS Windows version does not currently support cell-based margins, and the \
document margins are sometimes unreliable. Furthermore, they are stored in \
the binary portion of the notebook. All of this means that a notebook created \
in a Win-style front end will adopt the default margins of the target \
platform, which are usually suitable, but are rarely, if ever, identical. \
Conversely, margins specified in a Mac-style front end will not be used in a \
notebook ported to MS Windows. There is currently no solution to this \
difference of front end capabilities.\
\>", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
None of the front ends store page headers in the notebook text portion, so \
this is not portable. Also, the Win-style front ends do not currently allow \
you to use tabs in the running head to specify left, center, and right \
alignment. If notebooks are intended to be printed by the user, be aware that \
some characteristics will not be identical across platforms (or even across \
Mathematica installations).\
\>", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
All front ends are supposed to correctly handle notebooks using \
carriage-return(cr)/linefeed(lf) [MS-DOS style], cr [Macintosh style], and lf \
[Unix style] end-of-line indicators. However, problems have been encountered \
porting notebooks to the Macintosh and NeXT that can only be explained by \
incorrect handling of cr/lf, so currently you should run any notebook \
transported from a Win-style front end to other platforms through a file \
filter to convert to the correct end-of-line marker. Transferring a file by \
FTP using ASCII mode is generally a sufficient correction; Apple File \
Exchange can also be used. The current Win-style front end is generally good \
at handling end-of-line markers from other platforms.\
\>", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
\t\t\t\tASCII Codes\t\tControl Character
\tMacintosh\t\t13\t\t\t^M
\tUnix\t\t\t10\t\t\t^J
\tMS-DOS\t\t13 10\t\t\t^M^J\
\>", "Text",
  ImageRegion->{{0, 1}, {0, 1}}]
}, Closed]],

Cell[CellGroupData[{

Cell["Porting to Print", "Subsubtitle",
  TextAlignment->Center,
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
For some applications, it is useful to create an actual hard-copy document \
from the notebooks. Several issues peculiar to printing arise in this \
context.\
\>", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
Page breaking is often inappropriate, so you may need to examine the \
locations of page breaks, and reset them. Currently, this can only be done on \
a Mac-style front end.\
\>", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
Line graphics that use color should be carefully checked; the grayscales that \
the colors are translated to while printing need to be readily visible on the \
printed output.\
\>", "Text",
  ImageRegion->{{0, 1}, {0, 1}}]
}, Closed]]
}, Closed]]
}, Closed]]
},
FrontEndVersion->"4.1 for Microsoft Windows",
ScreenRectangle->{{0, 1400}, {0, 997}},
WindowToolbars->{},
CellGrouping->Manual,
WindowSize->{495, 740},
WindowMargins->{{216, Automatic}, {Automatic, 30}},
PrivateNotebookOptions->{"ColorPalette"->{RGBColor, -1}},
ShowCellLabel->True,
ShowCellTags->False,
RenderingOptions->{"ObjectDithering"->True,
"RasterDithering"->False}
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1727, 52, 120, 5, 170, "Title"],
Cell[1850, 59, 105, 4, 70, "Text"],
Cell[1958, 65, 402, 7, 70, "Text"],

Cell[CellGroupData[{
Cell[2385, 76, 108, 2, 70, "Subtitle"],
Cell[2496, 80, 528, 9, 70, "Text"],
Cell[3027, 91, 424, 7, 70, "Text"],
Cell[3454, 100, 646, 10, 70, "Text"],
Cell[4103, 112, 505, 8, 70, "Text"],
Cell[4611, 122, 557, 9, 70, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[5205, 136, 113, 2, 70, "Subtitle"],
Cell[5321, 140, 487, 8, 70, "Text"],
Cell[5811, 150, 460, 8, 70, "Text"],
Cell[6274, 160, 396, 7, 70, "Text"],
Cell[6673, 169, 800, 12, 70, "Text"],
Cell[7476, 183, 750, 12, 70, "Text"],
Cell[8229, 197, 399, 7, 70, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[8665, 209, 115, 2, 70, "Subtitle"],
Cell[8783, 213, 604, 10, 70, "Text"],
Cell[9390, 225, 725, 11, 70, "Text"],

Cell[CellGroupData[{
Cell[10140, 240, 86, 2, 70, "Subsubtitle"],
Cell[10229, 244, 357, 6, 70, "Text"],
Cell[10589, 252, 802, 12, 70, "Text"],
Cell[11394, 266, 617, 10, 70, "Text"],
Cell[12014, 278, 646, 10, 70, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[12697, 293, 89, 2, 70, "Subsubtitle"],
Cell[12789, 297, 289, 6, 70, "Text"],
Cell[13081, 305, 489, 8, 70, "Text"],
Cell[13573, 315, 349, 6, 70, "Text"],
Cell[13925, 323, 324, 6, 70, "Text"],
Cell[14252, 331, 198, 4, 70, "Text"],
Cell[14453, 337, 264, 5, 70, "Text"],
Cell[14720, 344, 755, 12, 70, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[15512, 361, 93, 2, 70, "Subsubtitle"],
Cell[15608, 365, 630, 10, 70, "Text"],
Cell[16241, 377, 470, 8, 70, "Text"],
Cell[16714, 387, 787, 12, 70, "Text"],
Cell[17504, 401, 174, 6, 70, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[17715, 412, 97, 2, 70, "Subsubtitle"],
Cell[17815, 416, 214, 5, 70, "Text"],
Cell[18032, 423, 230, 5, 70, "Text"],
Cell[18265, 430, 232, 5, 70, "Text"]
}, Closed]]
}, Closed]]
}, Closed]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

