(************** Content-type: application/mathematica **************

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     34785,       1222]*)
(*NotebookOutlinePosition[     35644,       1251]*)
(*  CellTagsIndexPosition[     35600,       1247]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["Introduction", "Title",
  TextAlignment->Center,
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
Version 2.0
2/12/92
Originally \"Tour Of Mathematica\"
by Wolfram Research
Modified by John Schneider & John Weiss                                       \
                 (Most modifications noted in \"Changes\" section)\
\>", "Subsubtitle",
  TextAlignment->Center,
  ImageRegion->{{0, 1}, {0, 1}}]
}, Closed]],

Cell[CellGroupData[{

Cell["Introduction to the Introduction", "Section",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
     This NoteBook presents several different aspects of Mathematica.  It \
does not provide a detailed discussion of Mathematica, but it will give you \
some examples of the capabilities of Mathematica and expose you to the \
NoteBook structure.

     In some sections of this NoteBook it is assumed that you have executed \
the previous commands.  So, it is best to work through the commands in the \
sequence presented.

     Here are some points about scrolling and cell structure that you will \
need to know.\
\>", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["Scrolling", "Subsection",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
     Using the mouse, click the scroll buttons in the bottom left of the \
window.  Your view of this file will scroll in the direction indicated by the \
arrow on the scroll button you choose.  Holding the mouse button down makes \
the scrolling continue until you release the button.  Notice that this \
scrolling causes the scroll bar to move vertically up and down.  The mouse \
can be used to directly drag the scroll bar to any desired position.\
\>", "Text",
  ImageRegion->{{0, 1}, {0, 1}}]
}, Closed]],

Cell[CellGroupData[{

Cell["Cell Structure", "Section",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
     NoteBooks are hierarchically structured in a manner similar to a table \
of contents in a book.  However, if one of the topics catches your eye, you \
do not thumb to the page corresponding to that topic;  rather, you double \
click on the cell grouping line that corresponds to that heading.  This will \
open the group and reveal individual cells that contain the text, formulae, \
and graphics associated with that heading.  A closed group of cells is \
indicated by a hook on the bottom of the cell grouping line.  An open \
grouping will not have a hook.  This section, \"Cell Structure,\" is an open \
group of cells.  There is a cell containing the title and the cell containing \
this text.  The grouping line is on the far right, and it does not have a \
hook on the bottom.  To close a group, double-click on the grouping line to \
the right.  You should notice how the pointer changes shape when in position \
to click on the cell bracket.  To open a group, double-click again on the \
hooked line. (From now on, it is up to you to open the group in which you are \
interested.)\
\>", "Text",
  ImageRegion->{{0, 1}, {0, 1}}]
}, Closed]],

Cell[CellGroupData[{

Cell["Numerical Calculations", "Section",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
     You can do arithmetic with Mathematica just as you would on a \
calculator.  You type the input 5 + 7, hit \"Enter\", and Mathematica prints \
the result 12.  Since 5 + 7 is already typed for you in the cell below, \
simply click anywhere in the cell below with the equation and then hit \
\"Enter.\"  Note that you must hit the \"Enter\" key (the one on the numeric \
key pad) to perform the calculation \[CapitalEth] not the return key.  \
Alternatively, you can hold the shift key and hit the return key.\
\>", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[BoxData[
    \(5 + 7\)], "Input",
  PageWidth->Infinity,
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
     Unlike a calculator, however, Mathematica can give you exact results.  \
Here is the exact result for 3 to the power 100.  The ^ is Mathematica \
notation for raising to a power.\
\>", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[BoxData[
    \(3\^100\)], "Input",
  PageWidth->Infinity,
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
     You can use the Mathematica function N to get approximate numerical \
results.  The % stands for the last result.  The answer is given in \
scientific notation.\
\>", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[BoxData[
    \(N[%]\)], "Input",
  PageWidth->Infinity,
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
     You can find numerical results to any degree of precision. This \
calculates the square root of 10 to 40 decimal places.  The text enclosed in \
the (* *) delimiters is ignored by Mathematica.\
\>", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[BoxData[
    \(N[\@10, 40]\)], "Input",
  PageWidth->Infinity,
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
     Mathematica can also handle complex numbers.  Here is (3 + i4)^10.  In \
Mathematica, \"I\" stands for the imaginary number square root of \
\[PlusMinus]1.\
\>", "Text",
  PageBreakAbove->True,
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[BoxData[
    \(\((3 + 4\ \[ImaginaryI])\)\^10\)], "Input",
  PageWidth->Infinity,
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
     Mathematica can evaluate all standard mathematical functions.  Here is \
the value of the Bessel function Jo(10.5).\
\>", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[BoxData[
    \(BesselJ[0, 10.5]\)], "Input",
  PageWidth->Infinity,
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
     You can do numerical integrals.  Here is the numerical value of the \
integral of sin(sin(x)) from 0 to p.\
\>", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[BoxData[
    \(NIntegrate[Sin[Sin[x]], {x, 0, \[Pi]}]\)], "Input",
  PageWidth->Infinity,
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
     Mathematica can do many kinds of exact computations with integers.  \
FactorInteger gives the factors of an integer.\
\>", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[BoxData[
    \(FactorInteger[20654065386]\)], "Input",
  PageWidth->Infinity,
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
     Note that all built-in Mathematica commands start with a capital letter.\
\
\>", "Text",
  ImageRegion->{{0, 1}, {0, 1}}]
}, Closed]],

Cell[CellGroupData[{

Cell["Delimiters", "Section",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[CellGroupData[{

Cell["Parentheses", "Subsection",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
     Parentheses are used for grouping.  Without parentheses, multiplication \
and division have a higher precedence than addition and subtraction.\
\>", "Text",
  ImageRegion->{{0, 1}, {0, 1}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Square Brackets", "Subsection",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
     Square brackets are used for specifying arguments to functions.  For \
example, the following statement calculates the square root of the sine of \
\[PlusMinus]p/2.\
\>", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[BoxData[
    \(\@Sin[\(-\(\[Pi]\/2\)\)]\)], "Input",
  PageWidth->Infinity,
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
     Some functions take a fixed number of arguments while others can be \
called with zero or more arguments.\
\>", "Text",
  ImageRegion->{{0, 1}, {0, 1}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Curly Braces", "Subsection",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
     Curly Braces are used for specifying lists, vectors, and matrices.  A \
list or vector is several expressions separated by commas and enclosed in \
curly braces.  The command shown below sets the variable \"m\" equal to a 3 \
by 3 matrix.\
\>", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[BoxData[
    \(m = {{1, 2, 3}, {4, 5, 6}, {7, 8, 9}}\)], "Input",
  PageWidth->Infinity,
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
     The function MatrixForm displays a matrix in a more conventional form.\
\>", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[BoxData[
    \(MatrixForm[m]\)], "Input",
  PageWidth->Infinity,
  ImageRegion->{{0, 1}, {0, 1}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Double Square Brackets", "Subsection",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
         Double square brackets are used for indexing, i.e., for referencing \
an object or set of objects in a list.  Suppose we have a vector \"v\" shown \
below.\
\>", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[BoxData[
    \(v = {b, c, d}\)], "Input",
  PageWidth->Infinity,
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
     The notation v[[i]] returns the ith element in the vector or list called \
\"v\".\
\>", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[BoxData[
    \(v\[LeftDoubleBracket]2\[RightDoubleBracket]\)], "Input",
  PageWidth->Infinity,
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
     Using the matrix \"m\", we can manipulate rows or elements. Recalling \
the assignment for \"m\" from the above section, we can add row 1 to row 2.\
\>", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[BoxData[
    \(m\[LeftDoubleBracket]2\[RightDoubleBracket] = 
      m\[LeftDoubleBracket]1\[RightDoubleBracket] + 
        m\[LeftDoubleBracket]2\[RightDoubleBracket]\)], "Input",
  PageWidth->Infinity,
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[BoxData[
    \(MatrixForm[m]\)], "Input",
  PageWidth->Infinity,
  ImageRegion->{{0, 1}, {0, 1}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Comments", "Subsection",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
     Text between (* and *) delimiters is not evaluated.  It is taken to be a \
comment. \
\>", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[BoxData[
    \(\@6. \)], "Input",
  PageWidth->Infinity,
  ImageRegion->{{0, 1}, {0, 1}}]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["On-line Help", "Section",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
     Most names of objects in Mathematica are complete words.  Mathematica \
rarely uses abbreviations.  Abbreviations are only used where they are well \
known.  For example:
     Abs     absolute value of a number
     Cos\t     cosine
     D         derivative
      
     The ? operator can be used to obtain online help.  The symbol * used \
with the ? operator acts as a wild card character, i.e., it can match any \
alphanumeric character or sequence of characters.  If more than one command \
matches the request, Mathematica lists the names of all the commands. 

     Given ?Plot* as input, Mathematica lists the commands that begin with \
the word Plot. \
\>", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[BoxData[
    \(Information["\<Plot*\>", LongForm \[Rule] False]\)], "Input",
  PageWidth->Infinity,
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
     If only one command matches the request, Mathematica will print the \
usage statement associated with the command.  The usage statement typically \
consists of a template showing how to use the command and a brief \
description.  Here is the information for Plot.\
\>", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[BoxData[
    \(Information["\<Plot\>", LongForm \[Rule] False]\)], "Input",
  PageWidth->Infinity,
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
     The usage statement tells us that this command plots a function over a \
specified domain.  For example, evaluate the command below. \
\>", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[BoxData[
    \(Plot[\[ExponentialE]\^\(-x\), {x, \(-1\), 5}]\)], "Input",
  PageWidth->Infinity,
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
     Use ?? to obtain more information.  (This often provides more detail \
than you need.)\
\>", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[BoxData[
    \(Information["\<Plot\>", LongForm \[Rule] True]\)], "Input",
  PageWidth->Infinity,
  ImageRegion->{{0, 1}, {0, 1}}]
}, Closed]],

Cell[CellGroupData[{

Cell["Editing", "Section",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[CellGroupData[{

Cell["Revising Text", "Subsection",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
     To change a single character or word, position the vertical I-beam \
pointer to the right of the item to be deleted, click the mouse once, and \
press the backspace key to remove the text.  To insert text, just begin \
typing.  For larger text revisions as well as entire cells, it is more \
efficient to use the Undo, Cut, Copy, and Paste keys.  These are described \
below.\
\>", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[CellGroupData[{

Cell["Undo", "Subsubsection",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
     Undo reverses your most recent typing or any editing action that used \
the Cut, Copy, or Paste keys.  It can be activated by simultaneously pressing \
the Command and Undo keys.\
\>", "Text",
  ImageRegion->{{0, 1}, {0, 1}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Cut", "Subsubsection",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
     Cut deletes selected text, graphics, or cells from your NoteBook and \
transfers them to the Pasteboard (special allocated memory).  To cut selected \
material from a Notebook and place it in the Pasteboard:

     1.  Select the material to be cut.  To select an entire cell, click its \
bracket.  To
           select text inside a cell, drag over the desired text with the \
mouse.
     2.  Press Command and the Cut keys simultaneously. \
\>", "Text",
  ImageRegion->{{0, 1}, {0, 1}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Copy", "Subsubsection",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
     Copy also moves selected text into the Pasteboard but, unlike the Cut \
command, it does not remove the selected text.\
\>", "Text",
  ImageRegion->{{0, 1}, {0, 1}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Paste", "Subsubsection",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
     This command inserts a copy of the Pasteboard contents at the current \
insertion point (chosen with the mouse).\
\>", "Text",
  ImageRegion->{{0, 1}, {0, 1}}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Creating New Cells", "Subsection",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
      You can create a new cell by placing the cell insertion point at the \
bottom or top edge of the existing cell and typing.  The mouse pointer will \
change to a horizontal I-beam when the mouse is properly positioned.\
\>", "Text",
  ImageRegion->{{0, 1}, {0, 1}}]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Graphics", "Section",
  PageBreakAbove->True,
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
     Here is a plot of the function sin(x3), with x ranging from \
\[PlusMinus]2 to 2.\
\>", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[BoxData[
    \(Plot[Sin[x\^3], {x, \(-2\), 2}]\)], "Input",
  PageWidth->Infinity,
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
     Mathematica chooses appropriate scales for plots, even when there are \
singularities.\
\>", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[BoxData[
    \(Plot[1\/Sin[x], {x, 0, 10}]\)], "Input",
  PageWidth->Infinity,
  ImageRegion->{{0, 1}, {0, 1}}]
}, Closed]],

Cell[CellGroupData[{

Cell["Three-Dimensional Plots", "Section",
  PageBreakAbove->True,
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
     This makes a contour plot of the function sin(x) sin(3y).\
\>", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[BoxData[
    \(ContourPlot[
      Sin[x]\ Sin[3\ y], {x, \(-2\), 2}, {y, \(-2\), 2}]\)], "Input",
  PageWidth->Infinity,
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["     Mathematica can also make three-dimensional pictures.", "Text",
  PageBreakAbove->True,
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[BoxData[
    \(Plot3D[Sin[x]\ Sin[3\ y], {x, \(-2\), 2}, {y, \(-2\), 2}]\)], "Input",
  PageWidth->Infinity,
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
     This displays the surface as seen from a different view point.\
\>", "Text",
  PageBreakAbove->True,
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[BoxData[
    \(Show[%, ViewPoint \[Rule] {1, 0, 1}]\)], "Input",
  PageWidth->Infinity,
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
     Here is the original picture, with a finer grid of sample points, and \
with shading determined by simulated illumination.\
\>", "Text",
  PageBreakAbove->True,
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[BoxData[
    \(Plot3D[Sin[x]\ Sin[3\ y], {x, \(-2\), 2}, {y, \(-2\), 2}, 
      PlotPoints \[Rule] 30, Lighting \[Rule] True]\)], "Input",
  PageWidth->Infinity,
  ImageRegion->{{0, 1}, {0, 1}}]
}, Closed]],

Cell["\<\

Ho cancellato le animazioni, per evitare ulteriori errori 
(8.12.98)
\
\>", "Input",
  PageWidth->Infinity,
  Evaluatable->False,
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[CellGroupData[{

Cell["Making Definitions", "Section",
  PageBreakAbove->True,
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["     This defines a value for the variable \"v\".", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[BoxData[
    \(v = 1 + x\)], "Input",
  PageWidth->Infinity,
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
     Now the value you have defined for \"v\" is used whenever v appears.\
\>", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[BoxData[
    \(5 + 2\ v + 3\ v\^2\)], "Input",
  PageWidth->Infinity,
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
     Expand[expr] expands out products and positive powers in expr.\
\>", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[BoxData[
    \(Expand[%]\)], "Input",
  PageWidth->Infinity,
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
     This defines a function \"f\".  The definition can be thought of as a \
rule for transforming expressions of the form f[anything].\
\>", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[BoxData[
    \(f[x_] := x\^2\)], "Input",
  PageWidth->Infinity,
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
     The occurrences of \"f\" in an expression like this are transformed \
according to the rules you have given.\
\>", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[BoxData[
    \(f[3] + f[a + b]\)], "Input",
  PageWidth->Infinity,
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
     You can define functions of multiple variables.  This defines the \
function \"f1\", which depends on two variables.\
\>", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[BoxData[
    \(f1[x_, y_] := 2\ x\^2 + x\ y + \@y\)], "Input",
  PageWidth->Infinity,
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
     Mathematica will evaluate as much of the expression as possible.  \
Unknowns are left as unknowns.  Here are two examples.\
\>", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[BoxData[
    \(f1[a, 4]\)], "Input",
  PageWidth->Infinity,
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[BoxData[
    \(f1[3, 4]\)], "Input",
  PageWidth->Infinity,
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["     Here is the recursive rule for the factorial function.", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[BoxData[
    \(fac[n_] := n\ fac[n - 1]\)], "Input",
  PageWidth->Infinity,
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
     This gives a rule for the end condition of the factorial function.\
\>", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[BoxData[
    \(fac[1] = 1\)], "Input",
  PageWidth->Infinity,
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["     Here are the two rules you have defined for fac.", "Text",
  PageBreakAbove->True,
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[BoxData[
    \(Information["\<fac\>", LongForm \[Rule] False]\)], "Input",
  PageWidth->Infinity,
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
     Mathematica can now apply these rules to find values for factorials.\
\>", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[BoxData[
    \(fac[20]\)], "Input",
  PageWidth->Infinity,
  ImageRegion->{{0, 1}, {0, 1}}]
}, Closed]],

Cell[CellGroupData[{

Cell["Algebraic Formulae", "Section",
  PageBreakAbove->True,
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
     Mathematica can work not only with numbers, but also with algebraic \
formulae.  Here is the formula (x + y)2 + 9 (2+x)(x+y).\
\>", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[BoxData[
    \(\((x + y)\)\^2 + 9\ \((2 + x)\)\ \((x + y)\)\)], "Input",
  PageWidth->Infinity,
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["     This does the algebra to expand products and powers.", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[BoxData[
    \(Expand[%]\)], "Input",
  PageWidth->Infinity,
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["     Here is the third power of the expression.", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[BoxData[
    \(%\^3\)], "Input",
  PageWidth->Infinity,
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
     Expanding this gives a somewhat more complicated result.\
\>", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[BoxData[
    \(Expand[%]\)], "Input",
  PageWidth->Infinity,
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
     Factoring the previous expression puts it in a much simpler form.\
\>", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[BoxData[
    \(Factor[%]\)], "Input",
  PageWidth->Infinity,
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
     Mathematica can do many kinds of algebraic computations.  This gives an \
exact formula for the integral of x/(1-x^3) dx.\
\>", "Text",
  PageBreakAbove->True,
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[BoxData[
    \(\[Integral]\(x\/\(1 - x\^3\)\) \[DifferentialD]x\)], "Input",
  PageWidth->Infinity,
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
     You can also find approximate formulae.  This computes the power series \
expansion of e\[PlusMinus]x sin(x) about the point x = 0 up to order x^6.\
\>", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[BoxData[
    \(Series[\[ExponentialE]\^\(-x\)\ Sin[2\ x], {x, 0, 6}]\)], "Input",
  PageWidth->Infinity,
  ImageRegion->{{0, 1}, {0, 1}}]
}, Closed]],

Cell[CellGroupData[{

Cell["Lists", "Section",
  PageBreakAbove->True,
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["     This makes a list of the first twenty factorials.", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[BoxData[
    \(Table[\(n!\), {n, 1, 20}]\)], "Input",
  PageWidth->Infinity,
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
     This takes the logarithm of each entry in the list, and evaluates the \
result numerically. Functions like Log have the property of being \
``listable'', so that they apply separately to each element in a list.\
\>", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[BoxData[
    \(N[Log[%]]\)], "Input",
  PageWidth->Infinity,
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["     Here is a plot of the entries in the list. ", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[BoxData[
    \(ListPlot[%]\)], "Input",
  PageWidth->Infinity,
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
     Mathematica uses lists to represent vectors.  Here is the dot product of \
two three-dimensional vectors.\
\>", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[BoxData[
    \({x, y, z} . {a, b, c}\)], "Input",
  PageWidth->Infinity,
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
     You can also do purely symbolic operations with lists.  Permutations \
gives all possible permutations of a list, i.e. all possible orderings of the \
elements in a list.\
\>", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[BoxData[
    \(Permutations[{a, b, c}]\)], "Input",
  PageWidth->Infinity,
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["     Flatten ``un-nests'' lists.", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[BoxData[
    \(Flatten[%]\)], "Input",
  PageWidth->Infinity,
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
     The list given as the permutations of {a,b,c} is actually a list of \
lists.  In this sense, the list is two dimensional.  Let us use the \
Permutations command again a set a variable equal to the output.  The list \
\"list1\" is essentially a matrix, as you will see in the next section.\
\>", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[BoxData[
    \(list1 = Permutations[{a, b, c}]\)], "Input",
  PageWidth->Infinity,
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
     The number of elements in each dimension of \"list1\" can be determined \
with the Dimensions command.  One of the dimensions of \"list1\" has 6 \
elements, and the second dimension has 3.\
\>", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[BoxData[
    \(Dimensions[list1]\)], "Input",
  PageWidth->Infinity,
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
     As noted in the Delimiters section, element locations within a list are \
specified with double brackets.  To get the second element of \"list1,\" we \
write:\
\>", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[BoxData[
    \(list1\[LeftDoubleBracket]2\[RightDoubleBracket]\)], "Input",
  PageWidth->Infinity,
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
     Notice that the second element is itself a list \[CapitalEth] one with \
three element.  To obtain the second element from this \"sub-list,\" we can \
add another subscript. \
\>", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[BoxData[
    \(list1\[LeftDoubleBracket]2, 2\[RightDoubleBracket]\)], "Input",
  PageWidth->Infinity,
  ImageRegion->{{0, 1}, {0, 1}}]
}, Closed]],

Cell[CellGroupData[{

Cell["Matrices", "Section",
  PageBreakAbove->True,
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
     This generates a matrix whose (i , j)th element is 1/(i+j+1).  \
Mathematica represents the matrix as a list of lists.\
\>", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[BoxData[
    \(m = Table[1\/\(i + j + 1\), {i, 3}, {j, 3}]\)], "Input",
  PageWidth->Infinity,
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
     The matrix can be displayed in matrix form rather than list form.\
\>", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[BoxData[
    \(MatrixForm[m]\)], "Input",
  PageWidth->Infinity,
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["     Here is the inverse of the matrix.", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[BoxData[
    \(Inverse[m]\)], "Input",
  PageWidth->Infinity,
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
     Multiplying the inverse by the original matrix gives an identity matrix.\
\
\>", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[BoxData[
    \(% . m\)], "Input",
  PageWidth->Infinity,
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["     This gives a new matrix, with a modified diagonal.", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[BoxData[
    \(m - x\ IdentityMatrix[3]\)], "Input",
  PageWidth->Infinity,
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
     The determinant of the new matrix gives the characteristic polynomial \
for the original matrix.\
\>", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[BoxData[
    \(Det[%]\)], "Input",
  PageWidth->Infinity,
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
     This finds (numerically) the roots of the characteristic polynomial \
using the Solve function.  These roots correspond to the eigenvalues of  \
\"m\".\
\>", "Text",
  PageBreakAbove->True,
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[BoxData[
    \(N[Solve[% == 0, x]]\)], "Input",
  PageWidth->Infinity,
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
     Using the function Eigenvalues, you can find the numerical eigenvalues \
of \"m\" directly.\
\>", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[BoxData[
    \(Eigenvalues[N[m]]\)], "Input",
  PageWidth->Infinity,
  ImageRegion->{{0, 1}, {0, 1}}]
}, Closed]],

Cell[CellGroupData[{

Cell["Procedural Programming", "Section",
  PageBreakAbove->True,
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
     Here is a simple Mathematica program that generates and expands \
products.  \
\>", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[BoxData[
    \(exprod[n_] := Expand[\[Product]\+\(i = 1\)\%n\((x + i)\)]\)], "Input",
  PageWidth->Infinity,
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
     The result of this function (or program) is the expansion of \
(x+1)(x+2)(x+3)...(x+n), where n is specified by you, the user.  The \
following statement runs the program with n=4.\
\>", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[BoxData[
    \(exprod[4]\)], "Input",
  PageWidth->Infinity,
  ImageRegion->{{0, 1}, {0, 1}}]
}, Closed]],

Cell[CellGroupData[{

Cell["Defining Mathematical Relations", "Section",
  PageBreakAbove->True,
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
     Here is an example of mathematical programming in Mathematica.   This \
definition gives the mathematical rule log(x y) = log(x) + log(y).\
\>", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[BoxData[
    \(log[x_\ y_] := log[x] + log[y]\)], "Input",
  PageWidth->Infinity,
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
     Mathematica uses your definition to expand out this logarithm.\
\>", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[BoxData[
    \(log[a\ b\ c\^2\ d]\)], "Input",
  PageWidth->Infinity,
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["     You can add the rule log(xn) = n log(x).", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[BoxData[
    \(log[x_\^n_] := n\ log[x]\)], "Input",
  PageWidth->Infinity,
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["     Now logarithms of powers are also expanded out.", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[BoxData[
    \(log[a\ b\ c\^2\ d]\)], "Input",
  PageWidth->Infinity,
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["     This shows all the definitions you have given for log.", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[BoxData[
    \(Information["\<log\>", LongForm \[Rule] False]\)], "Input",
  PageWidth->Infinity,
  ImageRegion->{{0, 1}, {0, 1}}]
}, Closed]],

Cell[CellGroupData[{

Cell["Changes", "Section",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
     This NoteBook was originally entitled \"TourOfMathematica.ma\" and was \
provided with the Mathematica distribution.  The modifications made are \
listed below.  This should not be of interest to the general reader.\
\>", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
     Changes on 2/12/92: reformated the notebook to agree with 2.0 \
formattting; changes \"pi\" in the text to p; indicated exponentiation with \
superscripts rather than \"^\".\
\>", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
     The font sizes were changed to agree with the default font sizes used in \
NeXT release 1.0 of Mathematica.  All the results were deleted so that the \
user must initiate the calculation.  All variables were enclosed in quotes in \
the text.\
\>", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
     The original introductory paragraph was deleted and the \"Introduction \
to the Introduction\" section was added.\
\>", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
     \"Numerical Calculations\" section:  Added statement about enter key.  \
Changed Rieman Zeta function to square root.  Added statement about \
Mathmatica commands starting with capital letters.  Added statement about \
comment delimiters.\
\>", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
     \"Cell Structure,\" \"On Line Help,\" \"Delimiters,\" and \"Editing\" \
sections were added.\
\>", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
     \"Graphics\" section:  The ?Function construct was further explained.\
\>", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
     \"Three-Dimensional Graphics\" section:  Deleted sentence about \
postscript output.\
\>", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["     \"Animations\" section was added.", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
     \"Algebraic Formulae\" section:  Deleted sentence about time to perform \
calculation.\
\>", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["     \"Solving Equations\" section was deleted.", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
     \"Lists\" section:  Statements about Fit function were deleted.  \
Statements about retrieving an element from a list were added.  Sentence \
about the ListPlot being nearly linear was deleted.\
\>", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
     \"Matrices\" section:  Statements about the symbolic determination of \
the eigenvalues were deleted.  Statements added to demonstrate MatrixForm.  \
The phrase \"leading diagonal\" was changed to just \"diagonal.\"\
\>", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
     \"Procedural Programming in Mathematica\" section:  Continued fraction \
example was deleted.  Some explanatory text was added.\
\>", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
     \"Defining Mathematical Relations in Mathematica\" section:  Typos were \
corrected (super- and sub-scripts were not properly rendered).  Statements \
about Laplace transform package were deleted.\
\>", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
     \"Interfacing with Mathematica\" section:  TeXForm statements were \
deleted.  OpenRead and ReadList statements were deleted.\
\>", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
     \"Making Definitions in Mathematica\" section:  Statements about \
defining w[2] were deleted.  Statements added about multi-variable functions. \
 Section was moved to follow \"Three-Dimensional Plots.\"\
\>", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["     \"More Graphics\" section was deleted.", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["     \"Mathematica Front Ends\" section was deleted.", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["     \"Notebooks\" section was deleted.", "Text",
  ImageRegion->{{0, 1}, {0, 1}}]
}, Closed]]
},
FrontEndVersion->"4.1 for Microsoft Windows",
ScreenRectangle->{{0, 1400}, {0, 997}},
WindowToolbars->{},
CellGrouping->Manual,
WindowSize->{495, 740},
WindowMargins->{{264, Automatic}, {Automatic, 90}},
PrivateNotebookOptions->{"ColorPalette"->{RGBColor, -1}},
ShowCellLabel->True,
ShowCellTags->False,
RenderingOptions->{"ObjectDithering"->True,
"RasterDithering"->False}
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1727, 52, 87, 2, 115, "Title"],
Cell[1817, 56, 310, 9, 70, "Subsubtitle"]
}, Closed]],

Cell[CellGroupData[{
Cell[2164, 70, 84, 1, 39, "Section"],
Cell[2251, 73, 571, 13, 70, "Text"],
Cell[2825, 88, 64, 1, 70, "Subsection"],
Cell[2892, 91, 508, 8, 70, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[3437, 104, 66, 1, 39, "Section"],
Cell[3506, 107, 1151, 17, 70, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[4694, 129, 74, 1, 39, "Section"],
Cell[4771, 132, 569, 9, 70, "Text"],
Cell[5343, 143, 94, 3, 70, "Input"],
Cell[5440, 148, 240, 5, 70, "Text"],
Cell[5683, 155, 95, 3, 70, "Input"],
Cell[5781, 160, 222, 5, 70, "Text"],
Cell[6006, 167, 93, 3, 70, "Input"],
Cell[6102, 172, 254, 5, 70, "Text"],
Cell[6359, 179, 100, 3, 70, "Input"],
Cell[6462, 184, 241, 6, 70, "Text",
  PageBreakAbove->True],
Cell[6706, 192, 119, 3, 70, "Input"],
Cell[6828, 197, 177, 4, 70, "Text"],
Cell[7008, 203, 105, 3, 70, "Input"],
Cell[7116, 208, 168, 4, 70, "Text"],
Cell[7287, 214, 127, 3, 70, "Input"],
Cell[7417, 219, 178, 4, 70, "Text"],
Cell[7598, 225, 115, 3, 70, "Input"],
Cell[7716, 230, 136, 4, 70, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[7889, 239, 62, 1, 39, "Section"],

Cell[CellGroupData[{
Cell[7976, 244, 66, 1, 70, "Subsection"],
Cell[8045, 247, 204, 4, 70, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[8286, 256, 70, 1, 70, "Subsection"],
Cell[8359, 259, 226, 5, 70, "Text"],
Cell[8588, 266, 113, 3, 70, "Input"],
Cell[8704, 271, 167, 4, 70, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[8908, 280, 67, 1, 70, "Subsection"],
Cell[8978, 283, 300, 6, 70, "Text"],
Cell[9281, 291, 126, 3, 70, "Input"],
Cell[9410, 296, 132, 3, 70, "Text"],
Cell[9545, 301, 102, 3, 70, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[9684, 309, 77, 1, 70, "Subsection"],
Cell[9764, 312, 221, 5, 70, "Text"],
Cell[9988, 319, 102, 3, 70, "Input"],
Cell[10093, 324, 143, 4, 70, "Text"],
Cell[10239, 330, 132, 3, 70, "Input"],
Cell[10374, 335, 209, 4, 70, "Text"],
Cell[10586, 341, 240, 5, 70, "Input"],
Cell[10829, 348, 102, 3, 70, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[10968, 356, 63, 1, 70, "Subsection"],
Cell[11034, 359, 146, 4, 70, "Text"],
Cell[11183, 365, 94, 3, 70, "Input"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[11326, 374, 64, 1, 39, "Section"],
Cell[11393, 377, 722, 16, 70, "Text"],
Cell[12118, 395, 137, 3, 70, "Input"],
Cell[12258, 400, 325, 6, 70, "Text"],
Cell[12586, 408, 136, 3, 70, "Input"],
Cell[12725, 413, 195, 4, 70, "Text"],
Cell[12923, 419, 134, 3, 70, "Input"],
Cell[13060, 424, 148, 4, 70, "Text"],
Cell[13211, 430, 135, 3, 70, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[13383, 438, 59, 1, 39, "Section"],

Cell[CellGroupData[{
Cell[13467, 443, 68, 1, 70, "Subsection"],
Cell[13538, 446, 437, 8, 70, "Text"],

Cell[CellGroupData[{
Cell[14000, 458, 62, 1, 70, "Subsubsection"],
Cell[14065, 461, 240, 5, 70, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[14342, 471, 61, 1, 70, "Subsubsection"],
Cell[14406, 474, 502, 11, 70, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[14945, 490, 62, 1, 70, "Subsubsection"],
Cell[15010, 493, 180, 4, 70, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[15227, 502, 63, 1, 70, "Subsubsection"],
Cell[15293, 505, 174, 4, 70, "Text"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[15516, 515, 73, 1, 70, "Subsection"],
Cell[15592, 518, 280, 5, 70, "Text"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[15921, 529, 84, 2, 39, "Section",
  PageBreakAbove->True],
Cell[16008, 533, 143, 4, 70, "Text"],
Cell[16154, 539, 120, 3, 70, "Input"],
Cell[16277, 544, 148, 4, 70, "Text"],
Cell[16428, 550, 116, 3, 70, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[16581, 558, 99, 2, 39, "Section",
  PageBreakAbove->True],
Cell[16683, 562, 119, 3, 70, "Text"],
Cell[16805, 567, 158, 4, 70, "Input"],
Cell[16966, 573, 131, 2, 70, "Text",
  PageBreakAbove->True],
Cell[17100, 577, 146, 3, 70, "Input"],
Cell[17249, 582, 148, 4, 70, "Text",
  PageBreakAbove->True],
Cell[17400, 588, 125, 3, 70, "Input"],
Cell[17528, 593, 208, 5, 70, "Text",
  PageBreakAbove->True],
Cell[17739, 600, 199, 4, 70, "Input"]
}, Closed]],
Cell[17953, 607, 173, 8, 81, "Input",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[18151, 619, 94, 2, 59, "Section",
  PageBreakAbove->True],
Cell[18248, 623, 98, 1, 70, "Text"],
Cell[18349, 626, 98, 3, 70, "Input"],
Cell[18450, 631, 130, 3, 70, "Text"],
Cell[18583, 636, 107, 3, 70, "Input"],
Cell[18693, 641, 124, 3, 70, "Text"],
Cell[18820, 646, 98, 3, 70, "Input"],
Cell[18921, 651, 192, 4, 70, "Text"],
Cell[19116, 657, 102, 3, 70, "Input"],
Cell[19221, 662, 170, 4, 70, "Text"],
Cell[19394, 668, 104, 3, 70, "Input"],
Cell[19501, 673, 178, 4, 70, "Text"],
Cell[19682, 679, 123, 3, 70, "Input"],
Cell[19808, 684, 184, 4, 70, "Text"],
Cell[19995, 690, 97, 3, 70, "Input"],
Cell[20095, 695, 97, 3, 70, "Input"],
Cell[20195, 700, 108, 1, 70, "Text"],
Cell[20306, 703, 113, 3, 70, "Input"],
Cell[20422, 708, 128, 3, 70, "Text"],
Cell[20553, 713, 99, 3, 70, "Input"],
Cell[20655, 718, 126, 2, 70, "Text",
  PageBreakAbove->True],
Cell[20784, 722, 135, 3, 70, "Input"],
Cell[20922, 727, 130, 3, 70, "Text"],
Cell[21055, 732, 96, 3, 70, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[21188, 740, 94, 2, 39, "Section",
  PageBreakAbove->True],
Cell[21285, 744, 187, 4, 70, "Text"],
Cell[21475, 750, 133, 3, 70, "Input"],
Cell[21611, 755, 106, 1, 70, "Text"],
Cell[21720, 758, 98, 3, 70, "Input"],
Cell[21821, 763, 96, 1, 70, "Text"],
Cell[21920, 766, 93, 3, 70, "Input"],
Cell[22016, 771, 118, 3, 70, "Text"],
Cell[22137, 776, 98, 3, 70, "Input"],
Cell[22238, 781, 127, 3, 70, "Text"],
Cell[22368, 786, 98, 3, 70, "Input"],
Cell[22469, 791, 207, 5, 70, "Text",
  PageBreakAbove->True],
Cell[22679, 798, 137, 3, 70, "Input"],
Cell[22819, 803, 209, 4, 70, "Text"],
Cell[23031, 809, 142, 3, 70, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[23210, 817, 81, 2, 39, "Section",
  PageBreakAbove->True],
Cell[23294, 821, 103, 1, 70, "Text"],
Cell[23400, 824, 114, 3, 70, "Input"],
Cell[23517, 829, 272, 5, 70, "Text"],
Cell[23792, 836, 98, 3, 70, "Input"],
Cell[23893, 841, 97, 1, 70, "Text"],
Cell[23993, 844, 100, 3, 70, "Input"],
Cell[24096, 849, 167, 4, 70, "Text"],
Cell[24266, 855, 110, 3, 70, "Input"],
Cell[24379, 860, 232, 5, 70, "Text"],
Cell[24614, 867, 112, 3, 70, "Input"],
Cell[24729, 872, 81, 1, 70, "Text"],
Cell[24813, 875, 99, 3, 70, "Input"],
Cell[24915, 880, 350, 6, 70, "Text"],
Cell[25268, 888, 120, 3, 70, "Input"],
Cell[25391, 893, 250, 5, 70, "Text"],
Cell[25644, 900, 106, 3, 70, "Input"],
Cell[25753, 905, 220, 5, 70, "Text"],
Cell[25976, 912, 136, 3, 70, "Input"],
Cell[26115, 917, 236, 5, 70, "Text"],
Cell[26354, 924, 139, 3, 70, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[26530, 932, 84, 2, 39, "Section",
  PageBreakAbove->True],
Cell[26617, 936, 180, 4, 70, "Text"],
Cell[26800, 942, 132, 3, 70, "Input"],
Cell[26935, 947, 127, 3, 70, "Text"],
Cell[27065, 952, 102, 3, 70, "Input"],
Cell[27170, 957, 88, 1, 70, "Text"],
Cell[27261, 960, 99, 3, 70, "Input"],
Cell[27363, 965, 136, 4, 70, "Text"],
Cell[27502, 971, 94, 3, 70, "Input"],
Cell[27599, 976, 104, 1, 70, "Text"],
Cell[27706, 979, 113, 3, 70, "Input"],
Cell[27822, 984, 158, 4, 70, "Text"],
Cell[27983, 990, 95, 3, 70, "Input"],
Cell[28081, 995, 237, 6, 70, "Text",
  PageBreakAbove->True],
Cell[28321, 1003, 108, 3, 70, "Input"],
Cell[28432, 1008, 153, 4, 70, "Text"],
Cell[28588, 1014, 106, 3, 70, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[28731, 1022, 98, 2, 39, "Section",
  PageBreakAbove->True],
Cell[28832, 1026, 139, 4, 70, "Text"],
Cell[28974, 1032, 146, 3, 70, "Input"],
Cell[29123, 1037, 242, 5, 70, "Text"],
Cell[29368, 1044, 98, 3, 70, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[29503, 1052, 107, 2, 39, "Section",
  PageBreakAbove->True],
Cell[29613, 1056, 200, 4, 70, "Text"],
Cell[29816, 1062, 119, 3, 70, "Input"],
Cell[29938, 1067, 124, 3, 70, "Text"],
Cell[30065, 1072, 107, 3, 70, "Input"],
Cell[30175, 1077, 94, 1, 70, "Text"],
Cell[30272, 1080, 113, 3, 70, "Input"],
Cell[30388, 1085, 101, 1, 70, "Text"],
Cell[30492, 1088, 107, 3, 70, "Input"],
Cell[30602, 1093, 108, 1, 70, "Text"],
Cell[30713, 1096, 135, 3, 70, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[30885, 1104, 59, 1, 70, "Section"],
Cell[30947, 1107, 277, 5, 70, "Text"],
Cell[31227, 1114, 235, 5, 70, "Text"],
Cell[31465, 1121, 303, 6, 70, "Text"],
Cell[31771, 1129, 175, 4, 70, "Text"],
Cell[31949, 1135, 300, 6, 70, "Text"],
Cell[32252, 1143, 154, 4, 70, "Text"],
Cell[32409, 1149, 131, 3, 70, "Text"],
Cell[32543, 1154, 146, 4, 70, "Text"],
Cell[32692, 1160, 87, 1, 70, "Text"],
Cell[32782, 1163, 148, 4, 70, "Text"],
Cell[32933, 1169, 96, 1, 70, "Text"],
Cell[33032, 1172, 255, 5, 70, "Text"],
Cell[33290, 1179, 277, 5, 70, "Text"],
Cell[33570, 1186, 189, 4, 70, "Text"],
Cell[33762, 1192, 258, 5, 70, "Text"],
Cell[34023, 1199, 187, 4, 70, "Text"],
Cell[34213, 1205, 266, 5, 70, "Text"],
Cell[34482, 1212, 92, 1, 70, "Text"],
Cell[34577, 1215, 101, 1, 70, "Text"],
Cell[34681, 1218, 88, 1, 70, "Text"]
}, Closed]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

